pub enum GuestFileErrorKind {
NotFound,
Io,
PermissionDenied,
OutOfSpace,
Unknown(u8),
}Expand description
Guest-side file operation error categories.
Variants
NotFound
The guest path does not exist or cannot be resolved.
Io
The guest reported a generic I/O failure.
PermissionDenied
The guest denied the requested file operation.
OutOfSpace
The guest filesystem did not have enough free space.
Unknown(u8)
The guest returned an unknown file-operation status code.