pub enum MicrovmState {
Created,
Ready,
Running,
Destroyed,
}Expand description
Lifecycle state of a MicrovmSandbox.
Variants
Created
Instance has been created but is not yet executable.
Ready
Instance is ready to execute commands or file operations.
Running
Instance is currently executing a command or transferring data.
Destroyed
Instance has been destroyed and cannot be reused.